@@ -7,10 +7,10 @@ import typing as t
 
 __title__       = "pyke"
 __author__      = "frissyn"
-__version__     = "0.0.3"
+__version__     = "0.0.4"
 __license__     = "MIT"
 __package__     = "pyke"
-__description__ = "Make-like build tool for Python."
+__description__ = "Makelike build tool for Python."
 
 tasks: t.Mapping = {}
 
@@ -19,6 +19,7 @@ from .task import get_task
 from .task import exec_task
 from .task import default_task
 
+from .core import env
 from .core import run
 from .core import shell
 from .core import export
